package com.bs.df.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bs.common.annotation.Log;
import com.bs.common.core.controller.BaseController;
import com.bs.common.core.domain.AjaxResult;
import com.bs.common.core.page.TableDataInfo;
import com.bs.common.enums.BusinessType;
import com.bs.common.utils.poi.ExcelUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import cn.hutool.core.lang.Validator;
import com.bs.df.domain.DfBizClue;
import com.bs.df.service.IDfBizClueService;
import javax.annotation.Resource;

/**
 * 业务线索Controller
 *
 * @author bs
 * @date 2024-04-06
 */
@Api(tags = "业务线索")
@RestController
@RequestMapping("/biz/clue")
public class DfBizClueController extends BaseController {
    @Resource
    private IDfBizClueService dfBizClueService;

    /**
     * 分页查询业务线索列表
     */
    @ApiOperation("分页查询业务线索列表")
    @GetMapping("/pageList")
    public TableDataInfo pageList(DfBizClue dfBizClue) {
        startPage();
        LambdaQueryWrapper<DfBizClue> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfBizClue);
        List<DfBizClue> list = dfBizClueService.list(queryWrapper);
        return getDataTable(list);
    }

    /**
     * 查询业务线索列表
     */
    @ApiOperation("查询业务线索列表")
    @GetMapping("/list")
    public AjaxResult list(DfBizClue dfBizClue) {
        LambdaQueryWrapper<DfBizClue> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfBizClue);
        List<DfBizClue> list = dfBizClueService.list(queryWrapper);
        return success(list);
    }

    /**
     * 导出业务线索列表
     */
    @ApiOperation("导出业务线索列表")
    @Log(title = "业务线索导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DfBizClue dfBizClue) {
        LambdaQueryWrapper<DfBizClue> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfBizClue);
        List<DfBizClue> list = dfBizClueService.list(queryWrapper);
        ExcelUtil<DfBizClue> util = new ExcelUtil<DfBizClue>(DfBizClue. class);
        util.exportExcel(response, list, "业务线索数据");
    }

    /**
     * 获取业务线索详细信息
     */
    @ApiOperation("获取业务线索详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(dfBizClueService.getById(id));
    }

    /**
     * 新增业务线索
     */
    @ApiOperation("新增业务线索")
    @Log(title = "业务线索新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DfBizClue dfBizClue) {
        return toAjax(dfBizClueService.save(dfBizClue));
    }

    /**
     * 修改业务线索
     */
    @ApiOperation("修改业务线索")
    @Log(title = "业务线索修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DfBizClue dfBizClue) {
        return toAjax(dfBizClueService.updateById(dfBizClue));
    }

    /**
     * 删除业务线索
     */
    @ApiOperation("删除业务线索")
    @Log(title = "业务线索删除", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids) {
        return toAjax(dfBizClueService.removeBatchByIds(ids));
    }

    /**
      * 条件设置
      */
    private void condition (LambdaQueryWrapper<DfBizClue> queryWrapper,DfBizClue dfBizClue){


        //id
        if(Validator.isNotEmpty(dfBizClue.getId())){
            queryWrapper.eq(DfBizClue::getId,dfBizClue.getId());
        }

        //数据类型0客户1经纪
        if(Validator.isNotEmpty(dfBizClue.getDataType())){
            queryWrapper.eq(DfBizClue::getDataType,dfBizClue.getDataType());
        }

        //线索类型
        if(Validator.isNotEmpty(dfBizClue.getClueType())){
            queryWrapper.eq(DfBizClue::getClueType,dfBizClue.getClueType());
        }

        //用户id
        if(Validator.isNotEmpty(dfBizClue.getUserId())){
            queryWrapper.eq(DfBizClue::getUserId,dfBizClue.getUserId());
        }

        //用户昵称
        if(Validator.isNotEmpty(dfBizClue.getNickName())){
            queryWrapper.eq(DfBizClue::getNickName,dfBizClue.getNickName());
        }

        //浏览时间
        if(Validator.isNotEmpty(dfBizClue.getBrowseTime())){
            queryWrapper.eq(DfBizClue::getBrowseTime,dfBizClue.getBrowseTime());
        }

        //创建部门
        if(Validator.isNotEmpty(dfBizClue.getCreateDept())){
            queryWrapper.eq(DfBizClue::getCreateDept,dfBizClue.getCreateDept());
        }

        //创建人员
        if(Validator.isNotEmpty(dfBizClue.getCreateBy())){
            queryWrapper.eq(DfBizClue::getCreateBy,dfBizClue.getCreateBy());
        }

        //创建时间
        if(Validator.isNotEmpty(dfBizClue.getCreateTime())){
            queryWrapper.eq(DfBizClue::getCreateTime,dfBizClue.getCreateTime());
        }

        //修改人员
        if(Validator.isNotEmpty(dfBizClue.getUpdateBy())){
            queryWrapper.eq(DfBizClue::getUpdateBy,dfBizClue.getUpdateBy());
        }

        //修改时间
        if(Validator.isNotEmpty(dfBizClue.getUpdateTime())){
            queryWrapper.eq(DfBizClue::getUpdateTime,dfBizClue.getUpdateTime());
        }

        //删除标志（0代表存在 2代表删除）
        if(Validator.isNotEmpty(dfBizClue.getDelFlag())){
            queryWrapper.eq(DfBizClue::getDelFlag,dfBizClue.getDelFlag());
        }

        //租户id
        if(Validator.isNotEmpty(dfBizClue.getTenantId())){
            queryWrapper.eq(DfBizClue::getTenantId,dfBizClue.getTenantId());
        }

        //${column.columnComment}
        if(Validator.isNotEmpty(dfBizClue.get业务链接())){
            queryWrapper.eq(DfBizClue::get业务链接,dfBizClue.get业务链接());
        }

        }

}
