package com.bs.df.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bs.common.annotation.Log;
import com.bs.common.core.controller.BaseController;
import com.bs.common.core.domain.AjaxResult;
import com.bs.common.core.page.TableDataInfo;
import com.bs.common.enums.BusinessType;
import com.bs.common.utils.poi.ExcelUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import cn.hutool.core.lang.Validator;
import com.bs.df.domain.DfOrder;
import com.bs.df.service.IDfOrderService;
import javax.annotation.Resource;

/**
 * 客户订单Controller
 *
 * @author bs
 * @date 2024-04-06
 */
@Api(tags = "客户订单")
@RestController
@RequestMapping("/order/order")
public class DfOrderController extends BaseController {
    @Resource
    private IDfOrderService dfOrderService;

    /**
     * 分页查询客户订单列表
     */
    @ApiOperation("分页查询客户订单列表")
    @GetMapping("/pageList")
    public TableDataInfo pageList(DfOrder dfOrder) {
        startPage();
        LambdaQueryWrapper<DfOrder> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfOrder);
        List<DfOrder> list = dfOrderService.list(queryWrapper);
        return getDataTable(list);
    }

    /**
     * 查询客户订单列表
     */
    @ApiOperation("查询客户订单列表")
    @GetMapping("/list")
    public AjaxResult list(DfOrder dfOrder) {
        LambdaQueryWrapper<DfOrder> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfOrder);
        List<DfOrder> list = dfOrderService.list(queryWrapper);
        return success(list);
    }

    /**
     * 导出客户订单列表
     */
    @ApiOperation("导出客户订单列表")
    @Log(title = "客户订单导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DfOrder dfOrder) {
        LambdaQueryWrapper<DfOrder> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfOrder);
        List<DfOrder> list = dfOrderService.list(queryWrapper);
        ExcelUtil<DfOrder> util = new ExcelUtil<DfOrder>(DfOrder. class);
        util.exportExcel(response, list, "客户订单数据");
    }

    /**
     * 获取客户订单详细信息
     */
    @ApiOperation("获取客户订单详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(dfOrderService.getById(id));
    }

    /**
     * 新增客户订单
     */
    @ApiOperation("新增客户订单")
    @Log(title = "客户订单新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DfOrder dfOrder) {
        return toAjax(dfOrderService.save(dfOrder));
    }

    /**
     * 修改客户订单
     */
    @ApiOperation("修改客户订单")
    @Log(title = "客户订单修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DfOrder dfOrder) {
        return toAjax(dfOrderService.updateById(dfOrder));
    }

    /**
     * 删除客户订单
     */
    @ApiOperation("删除客户订单")
    @Log(title = "客户订单删除", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids) {
        return toAjax(dfOrderService.removeBatchByIds(ids));
    }

    /**
      * 条件设置
      */
    private void condition (LambdaQueryWrapper<DfOrder> queryWrapper,DfOrder dfOrder){


        //id
        if(Validator.isNotEmpty(dfOrder.getId())){
            queryWrapper.eq(DfOrder::getId,dfOrder.getId());
        }

        //订单号
        if(Validator.isNotEmpty(dfOrder.getOrderNo())){
            queryWrapper.eq(DfOrder::getOrderNo,dfOrder.getOrderNo());
        }

        //客户id
        if(Validator.isNotEmpty(dfOrder.getUserId())){
            queryWrapper.eq(DfOrder::getUserId,dfOrder.getUserId());
        }

        //经纪id
        if(Validator.isNotEmpty(dfOrder.getBrokerId())){
            queryWrapper.eq(DfOrder::getBrokerId,dfOrder.getBrokerId());
        }

        //产品id
        if(Validator.isNotEmpty(dfOrder.getProductId())){
            queryWrapper.eq(DfOrder::getProductId,dfOrder.getProductId());
        }

        //产品名称
        if(Validator.isNotEmpty(dfOrder.getProductName())){
            queryWrapper.eq(DfOrder::getProductName,dfOrder.getProductName());
        }

        //提交时间
        if(Validator.isNotEmpty(dfOrder.getSubmitTime())){
            queryWrapper.eq(DfOrder::getSubmitTime,dfOrder.getSubmitTime());
        }

        //申请额（万元）
        if(Validator.isNotEmpty(dfOrder.getApplyAmount())){
            queryWrapper.eq(DfOrder::getApplyAmount,dfOrder.getApplyAmount());
        }

        //授信额（万元）
        if(Validator.isNotEmpty(dfOrder.getLimitAmount())){
            queryWrapper.eq(DfOrder::getLimitAmount,dfOrder.getLimitAmount());
        }

        //放款额（万元）
        if(Validator.isNotEmpty(dfOrder.getLoanAmount())){
            queryWrapper.eq(DfOrder::getLoanAmount,dfOrder.getLoanAmount());
        }

        //放款利率
        if(Validator.isNotEmpty(dfOrder.getLoanRate())){
            queryWrapper.eq(DfOrder::getLoanRate,dfOrder.getLoanRate());
        }

        //贷款期限（月）
        if(Validator.isNotEmpty(dfOrder.getLoadMonth())){
            queryWrapper.eq(DfOrder::getLoadMonth,dfOrder.getLoadMonth());
        }

        //是否首贷
        if(Validator.isNotEmpty(dfOrder.getIsFirst())){
            queryWrapper.eq(DfOrder::getIsFirst,dfOrder.getIsFirst());
        }

        //可结算金额（万元）
        if(Validator.isNotEmpty(dfOrder.getSettleAmount())){
            queryWrapper.eq(DfOrder::getSettleAmount,dfOrder.getSettleAmount());
        }

        //状态
        if(Validator.isNotEmpty(dfOrder.getStaus())){
            queryWrapper.eq(DfOrder::getStaus,dfOrder.getStaus());
        }

        //备注
        if(Validator.isNotEmpty(dfOrder.getRemark())){
            queryWrapper.eq(DfOrder::getRemark,dfOrder.getRemark());
        }

        //创建部门
        if(Validator.isNotEmpty(dfOrder.getCreateDept())){
            queryWrapper.eq(DfOrder::getCreateDept,dfOrder.getCreateDept());
        }

        //创建人员
        if(Validator.isNotEmpty(dfOrder.getCreateBy())){
            queryWrapper.eq(DfOrder::getCreateBy,dfOrder.getCreateBy());
        }

        //创建时间
        if(Validator.isNotEmpty(dfOrder.getCreateTime())){
            queryWrapper.eq(DfOrder::getCreateTime,dfOrder.getCreateTime());
        }

        //修改人员
        if(Validator.isNotEmpty(dfOrder.getUpdateBy())){
            queryWrapper.eq(DfOrder::getUpdateBy,dfOrder.getUpdateBy());
        }

        //修改时间
        if(Validator.isNotEmpty(dfOrder.getUpdateTime())){
            queryWrapper.eq(DfOrder::getUpdateTime,dfOrder.getUpdateTime());
        }

        //删除标志（0代表存在 2代表删除）
        if(Validator.isNotEmpty(dfOrder.getDelFlag())){
            queryWrapper.eq(DfOrder::getDelFlag,dfOrder.getDelFlag());
        }

        //租户id
        if(Validator.isNotEmpty(dfOrder.getTenantId())){
            queryWrapper.eq(DfOrder::getTenantId,dfOrder.getTenantId());
        }

        }

}
