package com.bs.df.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bs.common.annotation.Log;
import com.bs.common.core.controller.BaseController;
import com.bs.common.core.domain.AjaxResult;
import com.bs.common.core.page.TableDataInfo;
import com.bs.common.enums.BusinessType;
import com.bs.common.utils.poi.ExcelUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import cn.hutool.core.lang.Validator;
import com.bs.df.domain.DfProductInfo;
import com.bs.df.service.IDfProductInfoService;
import javax.annotation.Resource;

/**
 * 产品信息Controller
 *
 * @author bs
 * @date 2024-04-06
 */
@Api(tags = "产品信息")
@RestController
@RequestMapping("/product/info")
public class DfProductInfoController extends BaseController {
    @Resource
    private IDfProductInfoService dfProductInfoService;

    /**
     * 分页查询产品信息列表
     */
    @ApiOperation("分页查询产品信息列表")
    @GetMapping("/pageList")
    public TableDataInfo pageList(DfProductInfo dfProductInfo) {
        startPage();
        LambdaQueryWrapper<DfProductInfo> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfProductInfo);
        List<DfProductInfo> list = dfProductInfoService.list(queryWrapper);
        return getDataTable(list);
    }

    /**
     * 查询产品信息列表
     */
    @ApiOperation("查询产品信息列表")
    @GetMapping("/list")
    public AjaxResult list(DfProductInfo dfProductInfo) {
        LambdaQueryWrapper<DfProductInfo> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfProductInfo);
        List<DfProductInfo> list = dfProductInfoService.list(queryWrapper);
        return success(list);
    }

    /**
     * 导出产品信息列表
     */
    @ApiOperation("导出产品信息列表")
    @Log(title = "产品信息导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DfProductInfo dfProductInfo) {
        LambdaQueryWrapper<DfProductInfo> queryWrapper = new LambdaQueryWrapper();
        condition(queryWrapper,dfProductInfo);
        List<DfProductInfo> list = dfProductInfoService.list(queryWrapper);
        ExcelUtil<DfProductInfo> util = new ExcelUtil<DfProductInfo>(DfProductInfo. class);
        util.exportExcel(response, list, "产品信息数据");
    }

    /**
     * 获取产品信息详细信息
     */
    @ApiOperation("获取产品信息详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(dfProductInfoService.getById(id));
    }

    /**
     * 新增产品信息
     */
    @ApiOperation("新增产品信息")
    @Log(title = "产品信息新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DfProductInfo dfProductInfo) {
        return toAjax(dfProductInfoService.save(dfProductInfo));
    }

    /**
     * 修改产品信息
     */
    @ApiOperation("修改产品信息")
    @Log(title = "产品信息修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DfProductInfo dfProductInfo) {
        return toAjax(dfProductInfoService.updateById(dfProductInfo));
    }

    /**
     * 删除产品信息
     */
    @ApiOperation("删除产品信息")
    @Log(title = "产品信息删除", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids) {
        return toAjax(dfProductInfoService.removeBatchByIds(ids));
    }

    /**
      * 条件设置
      */
    private void condition (LambdaQueryWrapper<DfProductInfo> queryWrapper,DfProductInfo dfProductInfo){


        //产品id
        if(Validator.isNotEmpty(dfProductInfo.getId())){
            queryWrapper.eq(DfProductInfo::getId,dfProductInfo.getId());
        }

        //产品名称
        if(Validator.isNotEmpty(dfProductInfo.getProductName())){
            queryWrapper.eq(DfProductInfo::getProductName,dfProductInfo.getProductName());
        }

        //产品简称
        if(Validator.isNotEmpty(dfProductInfo.getSimpleName())){
            queryWrapper.eq(DfProductInfo::getSimpleName,dfProductInfo.getSimpleName());
        }

        //产品类型
        if(Validator.isNotEmpty(dfProductInfo.getProductType())){
            queryWrapper.eq(DfProductInfo::getProductType,dfProductInfo.getProductType());
        }

        //产品细类
        if(Validator.isNotEmpty(dfProductInfo.getProductSubtype())){
            queryWrapper.eq(DfProductInfo::getProductSubtype,dfProductInfo.getProductSubtype());
        }

        //最高额度（元）
        if(Validator.isNotEmpty(dfProductInfo.getMaxAmount())){
            queryWrapper.eq(DfProductInfo::getMaxAmount,dfProductInfo.getMaxAmount());
        }

        //年利率（单利）
        if(Validator.isNotEmpty(dfProductInfo.getInterestRate())){
            queryWrapper.eq(DfProductInfo::getInterestRate,dfProductInfo.getInterestRate());
        }

        //产品简介
        if(Validator.isNotEmpty(dfProductInfo.getProductIntro())){
            queryWrapper.eq(DfProductInfo::getProductIntro,dfProductInfo.getProductIntro());
        }

        //产品详情（富文本）
        if(Validator.isNotEmpty(dfProductInfo.getProductDetail())){
            queryWrapper.eq(DfProductInfo::getProductDetail,dfProductInfo.getProductDetail());
        }

        //上架时间起
        if(Validator.isNotEmpty(dfProductInfo.getListBegin())){
            queryWrapper.eq(DfProductInfo::getListBegin,dfProductInfo.getListBegin());
        }

        //上架时间止
        if(Validator.isNotEmpty(dfProductInfo.getListEnd())){
            queryWrapper.eq(DfProductInfo::getListEnd,dfProductInfo.getListEnd());
        }

        //状态0草稿1上架
        if(Validator.isNotEmpty(dfProductInfo.getStatus())){
            queryWrapper.eq(DfProductInfo::getStatus,dfProductInfo.getStatus());
        }

        //备注
        if(Validator.isNotEmpty(dfProductInfo.getRemark())){
            queryWrapper.eq(DfProductInfo::getRemark,dfProductInfo.getRemark());
        }

        //创建部门
        if(Validator.isNotEmpty(dfProductInfo.getCreateDept())){
            queryWrapper.eq(DfProductInfo::getCreateDept,dfProductInfo.getCreateDept());
        }

        //创建人员
        if(Validator.isNotEmpty(dfProductInfo.getCreateBy())){
            queryWrapper.eq(DfProductInfo::getCreateBy,dfProductInfo.getCreateBy());
        }

        //创建时间
        if(Validator.isNotEmpty(dfProductInfo.getCreateTime())){
            queryWrapper.eq(DfProductInfo::getCreateTime,dfProductInfo.getCreateTime());
        }

        //修改人员
        if(Validator.isNotEmpty(dfProductInfo.getUpdateBy())){
            queryWrapper.eq(DfProductInfo::getUpdateBy,dfProductInfo.getUpdateBy());
        }

        //修改时间
        if(Validator.isNotEmpty(dfProductInfo.getUpdateTime())){
            queryWrapper.eq(DfProductInfo::getUpdateTime,dfProductInfo.getUpdateTime());
        }

        //删除标志（0代表存在 2代表删除）
        if(Validator.isNotEmpty(dfProductInfo.getDelFlag())){
            queryWrapper.eq(DfProductInfo::getDelFlag,dfProductInfo.getDelFlag());
        }

        //租户id
        if(Validator.isNotEmpty(dfProductInfo.getTenantId())){
            queryWrapper.eq(DfProductInfo::getTenantId,dfProductInfo.getTenantId());
        }

        }

}
